@@ -148,11 +148,17 @@ class FastCNNApi(Resource):
         rtn['success'] = True
         return rtn
     
-    def startGrabbing(self):
+    def startGrabbing():
         #self.cam0 = CV2Camera()
         cam0.startCapture()
         
-        return self.cam0.isGrabbing()
+        return cam0.isGrabbing()
+    
+    def stopGrabbing():
+        #self.cam0 = CV2Camera()
+        cam0.stopCapture()
+        
+        return cam0.isGrabbing()
     
     def grabCapture():
         rtn = {"success":False}
@@ -191,7 +197,7 @@ class FastCNNApi(Resource):
             return FastCNNApi.predictYolo()
         
         if _cmd == "startGrabbing":
-            return self.startGrabbing()
+            return FastCNNApi.startGrabbing()
         
         if _cmd == "grabCapture":
-            return self.grabCapture()
\ No newline at end of file
+            return FastCNNApi.grabCapture()
\ No newline at end of file
