@@ -75,7 +75,7 @@ class ValidProxy:
     
     def setModel(self,projectid,modelid,mtype="valid"):
         config = ValidProxy.getConfig(projectid,modelid)
-        self._labels = sorted(config["LabelList"])
+        self._labels = config["LabelList"]
         
         net_name = config["Type"]
         
