@@ -27,6 +27,11 @@ Usage - formats:
 import argparse
 import os
 import sys
+
+import time
+import threading
+
+import numpy as np
 from pathlib import Path
 
 import torch
@@ -237,17 +242,76 @@ def main(opt):
     check_requirements(exclude=('tensorboard', 'thop'))
     run(**vars(opt))
 
+class ResourcePool:
+    def __init__(self,items):
+        self.cs = items
+        self.lock = threading.Lock()
+        pass
+    
+    def enPool(self,c):
+        self.lock.acquire()
+        self.cs.append(c)
+            
+        self.lock.release()
+        pass
+    
+    def dePool(self):
+        rtn = None
+        self.lock.acquire()
+        if len(self.cs):
+            rtn = self.cs.pop(0)
+            
+        self.lock.release()
+        return rtn
+    
+    def dePoolAsync(self):
+        item = self.dePool()
+        
+        while(item == None):
+            time.sleep(0.001)
+            item = self.dePool()
+        return item
+    
+    def getItems(self):
+        return self.cs
+    pass
+
 class SelectModel:
     def __init__(self):
-        self._model = None
+        
+        #self._model = None
+        self._pool = ResourcePool([None,None,None,None])
         pass
     
+    def size(self):
+        rtn = 0
+        if self._model:
+            rtn = sum([np.prod(list(p.size())) for p in self._model.parameters()]) *4/1000/1000
+        return rtn
+    
     def loadModel(self,projectid,modelid):
         saver = PathProxy.getValidCKPT(projectid,modelid)[:-1]
         
         device = select_device("")
-        self._model = DetectMultiBackend(saver, device=device, dnn=False, data=False, fp16=False)
+        #self._model = DetectMultiBackend(saver, device=device, dnn=False, data=False, fp16=False)
+        p = []
         
+        try:
+            for item in self._pool.getItems():
+                md = DetectMultiBackend(saver, device=device, dnn=False, data=False, fp16=False)
+                p.append(md)
+            
+            self._pool = ResourcePool(p)
+        except Exception as err:
+            print(err)
+    
+    def getModel(self):
+        model = self._pool.dePoolAsync()
+        return model
+    
+    def reModel(self,model):
+        self._pool.enPool(model)
+        pass
     
     def predictSingle(self,imgpath):
         device = select_device("")
@@ -266,11 +330,10 @@ class SelectModel:
         hide_labels=False  # hide labels
         hide_conf=False  # hide confidences
         
-        
-        
-        if not self._model:
+        #model = self._model
+        model = self.getModel()
+        if not model:
             return None
-        model = self._model
         stride, names, pt = model.stride, model.names, model.pt
         imgsz = check_img_size(imgsz, s=stride)  # check image size
 
@@ -357,7 +420,7 @@ class SelectModel:
                             rtn['results'] += str(round(cor,2))
                         
             rtn["spend"] = dt[0]+dt[1]+dt[2]
-                    
+        self.reModel(model)
         return rtn
 
 _model = SelectModel()
